package com.qmth.distributed.print.business.util.htmltopdf;

import com.qmth.distributed.print.business.config.DictionaryConfig;
import com.qmth.distributed.print.business.enums.PageSizeEnum;
import com.qmth.distributed.print.common.contant.SpringContextHolder;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.File;

/**
 * @Description: htmltopdf
 * @Param:
 * @return:
 * @Author: wangliang
 * @Date: 2021/4/7
 */
public class HtmlToPdfUtil {
    private final static Logger log = LoggerFactory.getLogger(HtmlToPdfUtil.class);

    /**
     * html转pdf
     *
     * @param srcPath
     * @param destPath
     * @param pageSizeEnum
     * @return
     */
    public static boolean convert(String srcPath, String destPath, PageSizeEnum pageSizeEnum) {
        File file = new File(destPath);
        File parent = file.getParentFile();
        // 如果pdf保存路径不存在，则创建路径
        if (!parent.exists()) {
            parent.mkdirs();
        }
        StringBuilder cmd = new StringBuilder();
//        if (System.getProperty("os.name").indexOf("Windows") == -1) {
        // 非windows 系统
//            toPdfTool = "/usr/local/bin/wkhtmltopdf";
//        }
        DictionaryConfig dictionaryConfig = SpringContextHolder.getBean(DictionaryConfig.class);
        cmd.append(dictionaryConfig.sysDomain().getHtmlToPdfUrl());
        cmd.append(" ");
        cmd.append(" --page-size ").append(pageSizeEnum.name()).append(" ");// 打A3
//        cmd.append("  --margin-top 3cm ");
//        cmd.append("  --page-size A4 ");// 打A4
//        cmd.append("  --header-line");// 页眉下面的线
//        cmd.append(" --header-center 这里是页眉这里是页眉这里是页眉这里是页眉 ");//页眉中间内容
//        cmd.append("  --margin-top 3cm ");// 设置页面上边距 (default 10mm)
//        //cmd.append(" --header-html  file:///" + "https://blog.csdn.net/x6582026/article/details/53835835");// (添加一个HTML页眉,后面是网址)
//        cmd.append(" --header-spacing 5 ");// (设置页眉和内容的距离,默认0)
//        cmd.append(" --footer-center 第[page]页／共[topage]页");//设置在中心位置的页脚内容
//        //cmd.append(" --footer-html  file:///" + "https://blog.csdn.net/x6582026/article/details/53835835");// (添加一个HTML页脚,后面是网址)
//        cmd.append(" --footer-line");// * 显示一条线在页脚内容上)
//        cmd.append(" --footer-spacing 5 ");// (设置页脚和内容的距离)
        cmd.append(srcPath);
        cmd.append(" ");
        cmd.append(destPath);

        log.info("proc:{}", cmd.toString());
        boolean result = true;
        try {
            Process proc = Runtime.getRuntime().exec(cmd.toString());
            new HtmlToPdfInterceptor(proc.getErrorStream()).start();
            new HtmlToPdfInterceptor(proc.getInputStream()).start();
            proc.waitFor();
        } catch (Exception e) {
            log.error("请求出错", e);
            result = false;
        }
        return result;
    }

//    public static void main(String[] args) {
////        HtmlToPdfUtil.convert("http://www.baidu.com", "/Users/king/Downloads/baidu.pdf", PageSizeEnum.A4);
//        String filename = "3120ee49668e4bf48fd8c161a2abb73b的副本";
//        HtmlToPdfUtil.convert("/Users/king/Downloads/测试附件/" + filename + ".html", "/Users/king/Downloads/pdf/" + filename + "A4.pdf", PageSizeEnum.A3);
//    }
}
